@@ -151,13 +151,18 @@ def ngettext(s_sing, s_plural, n, replace_sing=None, replace_plural=None):
 try:
     locale.setlocale(locale.LC_ALL, '')
 except locale.Error as error:
-    print(error)
+    print(error, file=sys.stderr)
 
 try:
     LANG = get_default_lang()
-    print('Found default language: %s' % LANG)
+    if os.name == 'nt':
+        # Set the env var on Windows because gettext.find() uses it to
+        # find the translation
+        # Use LANGUAGE instead of LANG, LANG sets LC_ALL and thus
+        # doesn't retain other region settings like LC_TIME
+        os.environ['LANGUAGE'] = LANG
 except Exception as error:
-    print('Failed to determine default language')
+    print('Failed to determine default language', file=sys.stderr)
     import traceback
     traceback.print_exc()
 
@@ -173,6 +178,6 @@ for dir_ in iter_locale_dirs():
     else:
         break
 else:
-    print('No translations found')
-    print('Dirs searched: %s' % get_locale_dirs())
+    print('No translations found', file=sys.stderr)
+    print('Dirs searched: %s' % get_locale_dirs(), file=sys.stderr)
     _ = _translation.gettext
