@@ -1,29 +1,34 @@
-##
-## Copyright (C) 2006 Gajim Team
-##
-## Gajim is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published
-## by the Free Software Foundation; version 3 only.
-##
-## Gajim is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# This file is part of Gajim.
+#
+# Gajim is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published
+# by the Free Software Foundation; version 3 only.
+#
+# Gajim is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 """
 Handles Jingle contents (XEP 0166)
 """
 
-import os
-import gajim
-import nbxmpp
-from jingle_xtls import SELF_SIGNED_CERTIFICATE
-from jingle_xtls import load_cert_file
+from typing import Any  # pylint: disable=unused-import
+from typing import Dict  # pylint: disable=unused-import
 
-contents = {}
+import os
+
+import nbxmpp
+
+from gajim.common import app
+from gajim.common import configpaths
+from gajim.common.jingle_xtls import SELF_SIGNED_CERTIFICATE
+from gajim.common.jingle_xtls import load_cert_file
+
+contents = {}  # type: Dict[str, Any]
 
 def get_jingle_content(node):
     namespace = node.getNamespace()
@@ -37,57 +42,64 @@ class JingleContentSetupException(Exception):
     """
 
 
-class JingleContent(object):
+class JingleContent:
     """
     An abstraction of content in Jingle sessions
     """
 
-    def __init__(self, session, transport):
+    def __init__(self, session, transport, senders):
         self.session = session
         self.transport = transport
         # will be filled by JingleSession.add_content()
         # don't uncomment these lines, we will catch more buggy code then
         # (a JingleContent not added to session shouldn't send anything)
-        #self.creator = None
-        #self.name = None
+        self.creator = None
+        self.name = None
         self.accepted = False
         self.sent = False
         self.negotiated = False
 
         self.media = None
 
-        self.senders = 'both' #FIXME
+        self.senders = senders
+        if self.senders is None:
+            self.senders = 'both'
+
         self.allow_sending = True # Used for stream direction, attribute 'senders'
 
+        # These were found by the Politie
+        self.file_props = None
+        self.use_security = None
+
         self.callbacks = {
-                # these are called when *we* get stanzas
-                'content-accept': [self.__on_transport_info,
-                        self.__on_content_accept],
-                'content-add': [self.__on_transport_info],
-                'content-modify': [],
-                'content-reject': [],
-                'content-remove': [],
-                'description-info': [],
-                'security-info': [],
-                'session-accept': [self.__on_transport_info,
-                        self.__on_content_accept],
-                'session-info': [],
-                'session-initiate': [self.__on_transport_info],
-                'session-terminate': [],
-                'transport-info': [self.__on_transport_info],
-                'transport-replace': [self.__on_transport_replace],
-                'transport-accept': [],
-                'transport-reject': [],
-                'iq-result': [],
-                'iq-error': [],
-                # these are called when *we* sent these stanzas
-                'content-accept-sent': [self.__fill_jingle_stanza,
-                        self.__on_content_accept],
-                'content-add-sent': [self.__fill_jingle_stanza],
-                'session-initiate-sent': [self.__fill_jingle_stanza],
-                'session-accept-sent': [self.__fill_jingle_stanza,
-                        self.__on_content_accept],
-                'session-terminate-sent': [],
+            # these are called when *we* get stanzas
+            'content-accept': [self.__on_transport_info,
+                               self.__on_content_accept],
+            'content-add': [self.__on_transport_info],
+            'content-modify': [],
+            'content-reject': [],
+            'content-remove': [],
+            'description-info': [],
+            'security-info': [],
+            'session-accept': [self.__on_transport_info,
+                               self.__on_content_accept],
+            'session-info': [],
+            'session-initiate': [self.__on_transport_info],
+            'session-terminate': [],
+            'transport-info': [self.__on_transport_info],
+            'transport-replace': [self.__on_transport_replace],
+            'transport-accept': [],
+            'transport-reject': [],
+            'iq-result': [],
+            'iq-error': [],
+            # these are called when *we* sent these stanzas
+            'content-accept-sent': [self.__fill_jingle_stanza,
+                                    self.__on_content_accept],
+            'content-add-sent': [self.__fill_jingle_stanza],
+            'session-initiate-sent': [self.__fill_jingle_stanza],
+            'session-accept-sent': [self.__fill_jingle_stanza,
+                                    self.__on_content_accept],
+            'session-terminate-sent': [],
         }
 
     def is_ready(self):
@@ -127,13 +139,17 @@ class JingleContent(object):
         if candidates:
             self.add_remote_candidates(candidates)
 
-    def __content(self, payload=[]):
+    def __content(self, payload=None):
         """
         Build a XML content-wrapper for our data
         """
+        if payload is None:
+            payload = []
         return nbxmpp.Node('content',
-                attrs={'name': self.name, 'creator': self.creator},
-                payload=payload)
+                           attrs={'name': self.name,
+                                  'creator': self.creator,
+                                  'senders': self.senders},
+                           payload=payload)
 
     def send_candidate(self, candidate):
         """
@@ -169,12 +185,8 @@ class JingleContent(object):
 
     def _fill_content(self, content):
         description_node = nbxmpp.simplexml.Node(
-            tag=nbxmpp.NS_JINGLE_FILE_TRANSFER + ' description')
-        if self.session.werequest:
-            simode = nbxmpp.simplexml.Node(tag='request')
-        else:
-            simode = nbxmpp.simplexml.Node(tag='offer')
-        file_tag = simode.setTag('file')
+            tag=nbxmpp.NS_JINGLE_FILE_TRANSFER_5 + ' description')
+        file_tag = description_node.setTag('file')
         if self.file_props.name:
             node = nbxmpp.simplexml.Node(tag='name')
             node.addData(self.file_props.name)
@@ -189,18 +201,17 @@ class JingleContent(object):
             file_tag.addChild(node=node)
         if self.file_props.type_ == 'r':
             if self.file_props.hash_:
-                h = file_tag.addChild('hash', attrs={
-                    'algo': self.file_props.algo}, namespace=nbxmpp.NS_HASHES,
-                    payload=self.file_props.hash_)
+                file_tag.addChild('hash', attrs={'algo': self.file_props.algo},
+                                  namespace=nbxmpp.NS_HASHES_2,
+                                  payload=self.file_props.hash_)
         else:
             # if the file is less than 10 mb, then it is small
             # lets calculate it right away
-            if self.file_props.size < 10000000 and not \
-                                        self.file_props.hash_:
-                h  = self._calcHash()
-                if h:
-                    file_tag.addChild(node=h)
-                pjid = gajim.get_jid_without_resource(self.session.peerjid)
+            if self.file_props.size < 10000000 and not self.file_props.hash_:
+                hash_data = self._compute_hash()
+                if hash_data:
+                    file_tag.addChild(node=hash_data)
+                pjid = app.get_jid_without_resource(self.session.peerjid)
                 file_info = {'name' : self.file_props.name,
                              'file-name' : self.file_props.file_name,
                              'hash' : self.file_props.hash_,
@@ -212,21 +223,21 @@ class JingleContent(object):
         desc = file_tag.setTag('desc')
         if self.file_props.desc:
             desc.setData(self.file_props.desc)
-        description_node.addChild(node=simode)
         if self.use_security:
             security = nbxmpp.simplexml.Node(
                 tag=nbxmpp.NS_JINGLE_XTLS + ' security')
-            certpath = os.path.join(gajim.MY_CERT_DIR, SELF_SIGNED_CERTIFICATE)\
-                + '.cert'
+            certpath = os.path.join(
+                configpaths.get('MY_CERT'), SELF_SIGNED_CERTIFICATE) + '.cert'
             cert = load_cert_file(certpath)
             if cert:
                 try:
-                    digest_algo = cert.get_signature_algorithm().split('With')[0]
-                except AttributeError, e:
+                    digest_algo = (cert.get_signature_algorithm()
+                                   .decode('utf-8').split('With')[0])
+                except AttributeError:
                     # Old py-OpenSSL is missing get_signature_algorithm
                     digest_algo = "sha256"
                 security.addChild('fingerprint').addData(cert.digest(
-                    digest_algo))
+                    digest_algo).decode('utf-8'))
                 for m in ('x509', ): # supported authentication methods
                     method = nbxmpp.simplexml.Node(tag='method')
                     method.setAttr('name', m)
@@ -237,5 +248,3 @@ class JingleContent(object):
     def destroy(self):
         self.callbacks = None
         del self.session.contents[(self.creator, self.name)]
-
-
