@@ -1,17 +1,16 @@
-##
-## Copyright (C) 2006 Gajim Team
-##
-## Gajim is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published
-## by the Free Software Foundation; version 3 only.
-##
-## Gajim is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# This file is part of Gajim.
+#
+# Gajim is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published
+# by the Free Software Foundation; version 3 only.
+#
+# Gajim is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 """
 Handles Jingle sessions (XEP 0166)
@@ -28,28 +27,31 @@ Handles Jingle sessions (XEP 0166)
 #   - Tie-breaking
 # * timeout
 
-import gajim #Get rid of that?
+import logging
+from enum import Enum, unique
+
 import nbxmpp
 
-from common.connection_handlers_events import JingleConnectedReceivedEvent, \
-    JingleErrorReceivedEvent, JingleTransferCancelledEvent, \
-    JingleRequestReceivedEvent, JingleDisconnectedReceivedEvent
-from common.file_props import FilesProp
-from jingle_transport import get_jingle_transport, JingleTransportIBB
-from jingle_content import get_jingle_content, JingleContentSetupException
-from jingle_content import JingleContent
-from jingle_ft import STATE_TRANSPORT_REPLACE
-import logging
-log = logging.getLogger("gajim.c.jingle_session")
+from gajim.common import app
+from gajim.common.jingle_transport import get_jingle_transport, JingleTransportIBB
+from gajim.common.jingle_content import get_jingle_content, JingleContentSetupException
+from gajim.common.jingle_ft import State
+from gajim.common.connection_handlers_events import (
+    FilesProp, JingleRequestReceivedEvent, JingleDisconnectedReceivedEvent,
+    JingleTransferCancelledEvent, JingleConnectedReceivedEvent,
+    JingleErrorReceivedEvent)
+
+log = logging.getLogger("app.c.jingle_session")
 
 # FIXME: Move it to JingleSession.States?
-class JingleStates(object):
+@unique
+class JingleStates(Enum):
     """
     States in which jingle session may exist
     """
-    ended = 0
-    pending = 1
-    active = 2
+    ENDED = 0
+    PENDING = 1
+    ACTIVE = 2
 
 class OutOfOrder(Exception):
     """
@@ -65,17 +67,18 @@ class TieBreak(Exception):
 
 class FailedApplication(Exception):
     """
-    Exception that should be raised in case responder supports none of the payload-types offered by the initiator
+    Exception that should be raised in case responder supports none of the
+    payload-types offered by the initiator
     """
 
-class JingleSession(object):
+class JingleSession:
     """
     This represents one jingle session, that is, one or more content types
     negotiated between an initiator and a responder.
     """
 
     def __init__(self, con, weinitiate, jid, iq_id=None, sid=None,
-                werequest=False):
+                 werequest=False):
         """
         con -- connection object,
         weinitiate -- boolean, are we the initiator?
@@ -84,22 +87,21 @@ class JingleSession(object):
         self.contents = {} # negotiated contents
         self.connection = con # connection to use
         # our full jid
-        #FIXME: Get rid of gajim here?
-        self.ourjid = gajim.get_jid_from_account(self.connection.name)
+        self.ourjid = app.get_jid_from_account(self.connection.name)
         if con.server_resource:
             self.ourjid = self.ourjid + '/' + con.server_resource
         self.peerjid = jid # jid we connect to
         # jid we use as the initiator
-        self.initiator = weinitiate and self.ourjid or self.peerjid
+        self.initiator = self.ourjid if weinitiate else self.peerjid
         # jid we use as the responder
-        self.responder = weinitiate and self.peerjid or self.ourjid
+        self.responder = self.peerjid if weinitiate else self.ourjid
         # are we an initiator?
         self.weinitiate = weinitiate
         # Are we requesting or offering a file?
         self.werequest = werequest
         self.request = False
         # what state is session in? (one from JingleStates)
-        self.state = JingleStates.ended
+        self.state = JingleStates.ENDED
         if not sid:
             sid = con.connection.getAnID()
         self.sid = sid # sessionid
@@ -111,37 +113,37 @@ class JingleSession(object):
             self.iq_ids = []
         self.accepted = True # is this session accepted by user
         # Tells whether this session is a file transfer or not
-        self.session_type_FT = False
+        self.session_type_ft = False
         # callbacks to call on proper contents
         # use .prepend() to add new callbacks, especially when you're going
         # to send error instead of ack
         self.callbacks = {
-                'content-accept':       [self.__ack, self.__on_content_accept,
-                                         self.__broadcast],
-                'content-add':          [self.__ack,
-                                        self.__on_content_add, self.__broadcast
-                                        ], #TODO
-                'content-modify':       [self.__ack], #TODO
-                'content-reject':       [self.__ack, self.__on_content_remove],
-                'content-remove':       [self.__ack, self.__on_content_remove],
-                'description-info':     [self.__ack, self.__broadcast], #TODO
-                'security-info':        [self.__ack], #TODO
-                'session-accept':       [self.__ack, self.__on_session_accept,
-                                         self.__on_content_accept,
-                                         self.__broadcast],
-                'session-info':         [self.__ack, self.__broadcast,
-                                         self.__on_session_info ],
-                'session-initiate':     [self.__ack, self.__on_session_initiate,
-                                         self.__broadcast],
-                'session-terminate':    [self.__ack,self.__on_session_terminate,
-                                         self.__broadcast_all],
-                'transport-info':       [self.__ack, self.__broadcast],
-                'transport-replace':    [self.__ack, self.__broadcast,
-                                         self.__on_transport_replace], #TODO
-                'transport-accept':     [self.__ack], #TODO
-                'transport-reject':     [self.__ack], #TODO
-                'iq-result':            [self.__broadcast],
-                'iq-error':             [self.__on_error],
+            'content-accept':       [self.__ack, self.__on_content_accept,
+                                     self.__broadcast],
+            'content-add':          [self.__ack,
+                                     self.__on_content_add, self.__broadcast
+                                    ], #TODO
+            'content-modify':       [self.__ack], #TODO
+            'content-reject':       [self.__ack, self.__on_content_remove],
+            'content-remove':       [self.__ack, self.__on_content_remove],
+            'description-info':     [self.__ack, self.__broadcast], #TODO
+            'security-info':        [self.__ack], #TODO
+            'session-accept':       [self.__ack, self.__on_session_accept,
+                                     self.__on_content_accept,
+                                     self.__broadcast],
+            'session-info':         [self.__ack, self.__broadcast,
+                                     self.__on_session_info],
+            'session-initiate':     [self.__ack, self.__on_session_initiate,
+                                     self.__broadcast],
+            'session-terminate':    [self.__ack, self.__on_session_terminate,
+                                     self.__broadcast_all],
+            'transport-info':       [self.__ack, self.__broadcast],
+            'transport-replace':    [self.__ack, self.__broadcast,
+                                     self.__on_transport_replace], #TODO
+            'transport-accept':     [self.__ack], #TODO
+            'transport-reject':     [self.__ack], #TODO
+            'iq-result':            [self.__broadcast],
+            'iq-error':             [self.__on_error],
         }
 
     def collect_iq_id(self, iq_id):
@@ -179,7 +181,7 @@ class JingleSession(object):
     def reject_content(self, media, name=None):
         content = self.get_content(media, name)
         if content:
-            if self.state == JingleStates.active:
+            if self.state == JingleStates.ACTIVE:
                 self.__content_reject(content)
             content.destroy()
             self.on_session_state_changed()
@@ -189,7 +191,7 @@ class JingleSession(object):
         Called when user stops or cancel session in UI
         """
         reason = nbxmpp.Node('reason')
-        if self.state == JingleStates.active:
+        if self.state == JingleStates.ACTIVE:
             reason.addChild('success')
         else:
             reason.addChild('cancel')
@@ -237,11 +239,11 @@ class JingleSession(object):
         if not self.contents:
             self.end_session()
 
-    def modify_content(self, creator, name, transport = None):
+    def modify_content(self, creator, name, transport=None):
         '''
         Currently used for transport replacement
         '''
-        content = self.contents[(creator,name)]
+        content = self.contents[(creator, name)]
         transport.set_sid(content.transport.sid)
         transport.set_file_props(content.transport.file_props)
         content.transport = transport
@@ -250,11 +252,11 @@ class JingleSession(object):
         content.accepted = True
 
     def on_session_state_changed(self, content=None):
-        if self.state == JingleStates.ended:
+        if self.state == JingleStates.ENDED:
             # Session not yet started, only one action possible: session-initiate
             if self.is_ready() and self.weinitiate:
                 self.__session_initiate()
-        elif self.state == JingleStates.pending:
+        elif self.state == JingleStates.PENDING:
             # We can either send a session-accept or a content-add
             if self.is_ready() and not self.weinitiate:
                 self.__session_accept()
@@ -262,7 +264,7 @@ class JingleSession(object):
                 self.__content_add(content)
             elif content and self.weinitiate:
                 self.__content_accept(content)
-        elif self.state == JingleStates.active:
+        elif self.state == JingleStates.ACTIVE:
             # We can either send a content-add or a content-accept. However, if
             # we are sending a file we can only use session_initiate.
             if not content:
@@ -282,7 +284,7 @@ class JingleSession(object):
         """
         Return True when all codecs and candidates are ready (for all contents)
         """
-        return (any((content.is_ready() for content in self.contents.itervalues()))
+        return (any((content.is_ready() for content in self.contents.values()))
                 and self.accepted)
 
     def accept_session(self):
@@ -303,20 +305,20 @@ class JingleSession(object):
         pass
 
     def send_content_accept(self, content):
-        assert self.state != JingleStates.ended
+        assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('content-accept')
         jingle.addChild(node=content)
         self.connection.connection.send(stanza)
 
     def send_transport_info(self, content):
-        assert self.state != JingleStates.ended
+        assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('transport-info')
         jingle.addChild(node=content)
         self.connection.connection.send(stanza)
         self.collect_iq_id(stanza.getID())
 
     def send_description_info(self, content):
-        assert self.state != JingleStates.ended
+        assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('description-info')
         jingle.addChild(node=content)
         self.connection.connection.send(stanza)
@@ -339,8 +341,8 @@ class JingleSession(object):
                 self.__send_error(stanza, 'bad-request')
                 return
             # FIXME: If we aren't initiated and it's not a session-initiate...
-            if action not in ['session-initiate','session-terminate'] \
-                    and self.state == JingleStates.ended:
+            if action not in ['session-initiate', 'session-terminate'] \
+                    and self.state == JingleStates.ENDED:
                 self.__send_error(stanza, 'item-not-found', 'unknown-session')
                 return
         else:
@@ -386,7 +388,7 @@ class JingleSession(object):
         transport = JingleTransportIBB()
         # For debug only, delete this and replace for a function
         # that will identify contents by its sid
-        for creator, name in self.contents.keys():
+        for creator, name in self.contents:
             self.modify_content(creator, name, transport)
             cont = self.contents[(creator, name)]
             cont.transport = transport
@@ -394,7 +396,7 @@ class JingleSession(object):
         self.__append_contents(jingle)
         self.__broadcast(stanza, jingle, None, 'transport-replace')
         self.connection.connection.send(stanza)
-        self.state = JingleStates.pending
+        self.state = JingleStates.PENDING
 
     def __on_transport_replace(self, stanza, jingle, error, action):
         for content in jingle.iterTags('content'):
@@ -410,25 +412,24 @@ class JingleSession(object):
                 elif transport_ns == nbxmpp.NS_JINGLE_IBB:
                     transport = JingleTransportIBB()
                     self.modify_content(creator, name, transport)
-                    self.state = JingleStates.pending
-                    self.contents[(creator,name)].state = STATE_TRANSPORT_REPLACE
+                    self.state = JingleStates.PENDING
+                    self.contents[(creator, name)].state = State.TRANSPORT_REPLACE
                     self.__ack(stanza, jingle, error, action)
                     self.__session_accept()
-                    self.contents[(creator,name)].start_IBB_transfer()
                 else:
                     stanza, jingle = self.__make_jingle('transport-reject')
                     content = jingle.setTag('content', attrs={'creator': creator,
-                            'name': name})
+                                                              'name': name})
                     content.setTag('transport', namespace=transport_ns)
                     self.connection.connection.send(stanza)
                     raise nbxmpp.NodeProcessed
             else:
-                # FIXME: This ressource is unknown to us, what should we do?
+                # FIXME: This resource is unknown to us, what should we do?
                 # For now, reject the transport
                 stanza, jingle = self.__make_jingle('transport-reject')
-                c = jingle.setTag('content', attrs={'creator': creator,
-                        'name': name})
-                c.setTag('transport', namespace=transport_ns)
+                content = jingle.setTag('content', attrs={'creator': creator,
+                                                          'name': name})
+                content.setTag('transport', namespace=transport_ns)
                 self.connection.connection.send(stanza)
                 raise nbxmpp.NodeProcessed
 
@@ -438,14 +439,16 @@ class JingleSession(object):
         if payload[0].getName() == 'ringing':
             # ignore ringing
             raise nbxmpp.NodeProcessed
-        if self.state != JingleStates.active:
+        if self.state != JingleStates.ACTIVE:
             raise OutOfOrder
-        for p in payload:
-            if p.getName() == 'checksum':
-                hash_ = p.getTag('file').getTag(name='hash',
-                    namespace=nbxmpp.NS_HASHES)
+        for child in payload:
+            if child.getName() == 'checksum':
+                hash_ = child.getTag('file').getTag(name='hash',
+                                                    namespace=nbxmpp.NS_HASHES_2)
+                if hash_ is None:
+                    continue
                 algo = hash_.getAttr('algo')
-                if algo in nbxmpp.Hashes.supported:
+                if algo in nbxmpp.Hashes2.supported:
                     file_props = FilesProp.getFileProp(self.connection.name,
                                                        self.sid)
                     file_props.algo = algo
@@ -462,7 +465,7 @@ class JingleSession(object):
             if (creator, name) in self.contents:
                 content = self.contents[(creator, name)]
                 # TODO: this will fail if content is not an RTP content
-                gajim.nec.push_incoming_event(JingleDisconnectedReceivedEvent(
+                app.nec.push_incoming_event(JingleDisconnectedReceivedEvent(
                     None, conn=self.connection, jingle_session=self,
                     media=content.media, reason='removed'))
                 content.destroy()
@@ -473,42 +476,44 @@ class JingleSession(object):
 
     def __on_session_accept(self, stanza, jingle, error, action):
         # FIXME
-        if self.state != JingleStates.pending:
+        if self.state != JingleStates.PENDING:
             raise OutOfOrder
-        self.state = JingleStates.active
+        self.state = JingleStates.ACTIVE
 
-    def __on_content_accept(self, stanza, jingle, error, action):
+    @staticmethod
+    def __on_content_accept(stanza, jingle, error, action):
         """
         Called when we get content-accept stanza or equivalent one (like
         session-accept)
         """
         # check which contents are accepted
-        for content in jingle.iterTags('content'):
-            creator = content['creator']
-            # TODO
-            name = content['name']
+        # for content in jingle.iterTags('content'):
+        #     creator = content['creator']
+        #     name = content['name']
+        return
 
     def __on_content_add(self, stanza, jingle, error, action):
-        if self.state == JingleStates.ended:
+        if self.state == JingleStates.ENDED:
             raise OutOfOrder
         parse_result = self.__parse_contents(jingle)
         contents = parse_result[0]
-        rejected_contents = parse_result[1]
-        for name, creator in rejected_contents:
-            # TODO
-            content = JingleContent()
-            self.add_content(name, content, creator)
-            self.__content_reject(content)
-            self.contents[(content.creator, content.name)].destroy()
-        gajim.nec.push_incoming_event(JingleRequestReceivedEvent(None,
-            conn=self.connection, jingle_session=self, contents=contents))
+        # rejected_contents = parse_result[1]
+        # for name, creator in rejected_contents:
+        #     content = JingleContent()
+        #     self.add_content(name, content, creator)
+        #     self.__content_reject(content)
+        #     self.contents[(content.creator, content.name)].destroy()
+        app.nec.push_incoming_event(JingleRequestReceivedEvent(None,
+                                                                 conn=self.connection,
+                                                                 jingle_session=self,
+                                                                 contents=contents))
 
     def __on_session_initiate(self, stanza, jingle, error, action):
         """
         We got a jingle session request from other entity, therefore we are the
         receiver... Unpack the data, inform the user
         """
-        if self.state != JingleStates.ended:
+        if self.state != JingleStates.ENDED:
             raise OutOfOrder
         self.initiator = jingle['initiator']
         self.responder = self.ourjid
@@ -519,12 +524,22 @@ class JingleSession(object):
         # Jingle with unknown entities, it SHOULD return a <service-unavailable/>
         # error.
         # Lets check what kind of jingle session does the peer want
-        contents, contents_rejected, reason_txt = self.__parse_contents(jingle)
-        # If we are not receivin a file
+        contents, _contents_rejected, reason_txt = self.__parse_contents(jingle)
+
+        # If there's no content we understand...
+        if not contents:
+            # TODO: http://xmpp.org/extensions/xep-0166.html#session-terminate
+            reason = nbxmpp.Node('reason')
+            reason.setTag(reason_txt)
+            self.__ack(stanza, jingle, error, action)
+            self._session_terminate(reason)
+            raise nbxmpp.NodeProcessed
+
+        # If we are not receiving a file
         # Check if there's already a session with this user:
-        if contents[0][0] != 'file':
+        if contents[0].media != 'file':
             for session in self.connection.iter_jingle_sessions(self.peerjid):
-                if not session is self:
+                if session is not self:
                     reason = nbxmpp.Node('reason')
                     alternative_session = reason.setTag('alternative-session')
                     alternative_session.setTagData('sid', session.sid)
@@ -534,36 +549,29 @@ class JingleSession(object):
         else:
             # Stop if we don't have the requested file or the peer is not
             # allowed to request the file
-            request = \
-                 jingle.getTag('content').getTag('description').getTag('request')
+            request = contents[0].senders == 'responder'
             if request:
                 self.request = True
-                h = request.getTag('file').getTag('hash')
-                h = h.getData() if h else None
+                hash_tag = request.getTag('file').getTag('hash')
+                hash_data = hash_tag.getData() if hash_tag else None
                 n = request.getTag('file').getTag('name')
                 n = n.getData() if n else None
-                pjid = gajim.get_jid_without_resource(self.peerjid)
-                file_info = self.connection.get_file_info(pjid, h, n,
-                                                     self.connection.name)
+                pjid = app.get_jid_without_resource(self.peerjid)
+                file_info = self.connection.get_file_info(pjid, hash_data, n,
+                                                          self.connection.name)
                 if not file_info:
-                    log.warning('The peer ' + pjid + \
-                                ' is requesting a ' + \
-                                'file that we dont have or ' + \
-                                'it is not allowed to request')
+                    log.warning('The peer %s is requesting a ' \
+                                'file that we dont have or ' \
+                                'it is not allowed to request', pjid)
                     self.decline_session()
                     raise nbxmpp.NodeProcessed
-        # If there's no content we understand...
-        if not contents:
-            # TODO: http://xmpp.org/extensions/xep-0166.html#session-terminate
-            reason = nbxmpp.Node('reason')
-            reason.setTag(reason_txt)
-            self.__ack(stanza, jingle, error, action)
-            self._session_terminate(reason)
-            raise nbxmpp.NodeProcessed
-        self.state = JingleStates.pending
+
+        self.state = JingleStates.PENDING
         # Send event about starting a session
-        gajim.nec.push_incoming_event(JingleRequestReceivedEvent(None,
-            conn=self.connection, jingle_session=self, contents=contents))
+        app.nec.push_incoming_event(JingleRequestReceivedEvent(None,
+                                                                 conn=self.connection,
+                                                                 jingle_session=self,
+                                                                 contents=contents[0]))
 
     def __broadcast(self, stanza, jingle, error, action):
         """
@@ -599,16 +607,18 @@ class JingleSession(object):
         else:
             # TODO
             text = reason
-        if reason == 'cancel' and self.session_type_FT:
-            gajim.nec.push_incoming_event(JingleTransferCancelledEvent(None,
-                conn=self.connection, jingle_session=self, media=None,
-                reason=text))
+        if reason == 'cancel' and self.session_type_ft:
+            app.nec.push_incoming_event(JingleTransferCancelledEvent(None,
+                                                                       conn=self.connection,
+                                                                       jingle_session=self,
+                                                                       media=None,
+                                                                       reason=text))
 
     def __broadcast_all(self, stanza, jingle, error, action):
         """
         Broadcast the stanza to all content handlers
         """
-        for content in self.contents.itervalues():
+        for content in self.contents.values():
             content.on_stanza(stanza, None, error, action)
 
     def __parse_contents(self, jingle):
@@ -624,10 +634,10 @@ class JingleSession(object):
             if content_type:
                 try:
                     if transport:
-                        content = content_type(self, transport)
+                        content = content_type(self, transport=transport)
                         self.add_content(element['name'],
-                                content, 'peer')
-                        contents.append((content.media,))
+                                         content, 'peer')
+                        contents.append(content)
                     else:
                         reasons.add('unsupported-transports')
                         contents_rejected.append((element['name'], 'peer'))
@@ -639,7 +649,7 @@ class JingleSession(object):
         failure_reason = None
         # Store the first reason of failure
         for reason in ('failed-application', 'unsupported-transports',
-                'unsupported-applications'):
+                       'unsupported-applications'):
             if reason in reasons:
                 failure_reason = reason
                 break
@@ -649,18 +659,22 @@ class JingleSession(object):
         if text:
             text = '%s (%s)' % (error, text)
         if type_ != 'modify':
-            gajim.nec.push_incoming_event(JingleErrorReceivedEvent(None,
-                conn=self.connection, jingle_session=self,
-                reason=text or error))
+            app.nec.push_incoming_event(JingleErrorReceivedEvent(None,
+                                                                   conn=self.connection,
+                                                                   jingle_session=self,
+                                                                   reason=text or error))
 
-    def __reason_from_stanza(self, stanza):
+    @staticmethod
+    def __reason_from_stanza(stanza):
         # TODO: Move to GUI?
         reason = 'success'
-        reasons = ['success', 'busy', 'cancel', 'connectivity-error',
-                'decline', 'expired', 'failed-application', 'failed-transport',
-                'general-error', 'gone', 'incompatible-parameters', 'media-error',
-                'security-error', 'timeout', 'unsupported-applications',
-                'unsupported-transports']
+        reasons = [
+            'success', 'busy', 'cancel', 'connectivity-error', 'decline',
+            'expired', 'failed-application', 'failed-transport',
+            'general-error', 'gone', 'incompatible-parameters', 'media-error',
+            'security-error', 'timeout', 'unsupported-applications',
+            'unsupported-transports'
+        ]
         tag = stanza.getTag('reason')
         text = ''
         if tag:
@@ -673,12 +687,14 @@ class JingleSession(object):
 
     def __make_jingle(self, action, reason=None):
         stanza = nbxmpp.Iq(typ='set', to=nbxmpp.JID(self.peerjid),
-            frm=self.ourjid)
-        attrs = {'action': action,
-                'sid': self.sid,
-                'initiator' : self.initiator}
+                           frm=self.ourjid)
+        attrs = {
+            'action': action,
+            'sid': self.sid,
+            'initiator' : self.initiator
+        }
         jingle = stanza.addChild('jingle', attrs=attrs,
-            namespace=nbxmpp.NS_JINGLE)
+                                 namespace=nbxmpp.NS_JINGLE)
         if reason is not None:
             jingle.addChild(node=reason)
         return stanza, jingle
@@ -695,13 +711,15 @@ class JingleSession(object):
         self.connection.connection.send(err_stanza)
         self.__dispatch_error(jingle_error or error, text, type_)
 
-    def __append_content(self, jingle, content):
+    @staticmethod
+    def __append_content(jingle, content):
         """
-        Append <content/> element to <jingle/> element, with (full=True) or
-        without (full=False) <content/> children
+        Append <content/> element to <jingle/> element
         """
         jingle.addChild('content',
-                attrs={'name': content.name, 'creator': content.creator})
+                        attrs={'name': content.name,
+                               'creator': content.creator,
+                               'senders': content.senders})
 
     def __append_contents(self, jingle):
         """
@@ -714,36 +732,36 @@ class JingleSession(object):
                 self.__append_content(jingle, content)
 
     def __session_initiate(self):
-        assert self.state == JingleStates.ended
+        assert self.state == JingleStates.ENDED
         stanza, jingle = self.__make_jingle('session-initiate')
         self.__append_contents(jingle)
         self.__broadcast(stanza, jingle, None, 'session-initiate-sent')
         self.connection.connection.send(stanza)
         self.collect_iq_id(stanza.getID())
-        self.state = JingleStates.pending
+        self.state = JingleStates.PENDING
 
     def __session_accept(self):
-        assert self.state == JingleStates.pending
+        assert self.state == JingleStates.PENDING
         stanza, jingle = self.__make_jingle('session-accept')
         self.__append_contents(jingle)
         self.__broadcast(stanza, jingle, None, 'session-accept-sent')
         self.connection.connection.send(stanza)
         self.collect_iq_id(stanza.getID())
-        self.state = JingleStates.active
+        self.state = JingleStates.ACTIVE
 
     def __session_info(self, payload=None):
-        assert self.state != JingleStates.ended
+        assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('session-info')
         if payload:
             jingle.addChild(node=payload)
         self.connection.connection.send(stanza)
 
-    def _JingleFileTransfer__session_info(self, p):
+    def _JingleFileTransfer__session_info(self, payload):
         # For some strange reason when I call
-        # self.session.__session_info(h) from the jingleFileTransfer object
+        # self.session.__session_info(payload) from the jingleFileTransfer object
         # within a thread, this method gets called instead. Even though, it
         # isn't being called explicitly.
-        self.__session_info(p)
+        self.__session_info(payload)
 
     def _session_terminate(self, reason=None):
         stanza, jingle = self.__make_jingle('session-terminate', reason=reason)
@@ -759,13 +777,15 @@ class JingleSession(object):
         else:
             text = reason
         self.connection.delete_jingle_session(self.sid)
-        gajim.nec.push_incoming_event(JingleDisconnectedReceivedEvent(None,
-            conn=self.connection, jingle_session=self, media=None,
-            reason=text))
+        app.nec.push_incoming_event(JingleDisconnectedReceivedEvent(None,
+                                                                      conn=self.connection,
+                                                                      jingle_session=self,
+                                                                      media=None,
+                                                                      reason=text))
 
     def __content_add(self, content):
         # TODO: test
-        assert self.state != JingleStates.ended
+        assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('content-add')
         self.__append_content(jingle, content)
         self.__broadcast(stanza, jingle, None, 'content-add-sent')
@@ -774,7 +794,7 @@ class JingleSession(object):
 
     def __content_accept(self, content):
         # TODO: test
-        assert self.state != JingleStates.ended
+        assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('content-accept')
         self.__append_content(jingle, content)
         self.__broadcast(stanza, jingle, None, 'content-accept-sent')
@@ -782,31 +802,35 @@ class JingleSession(object):
         self.collect_iq_id(id_)
 
     def __content_reject(self, content):
-        assert self.state != JingleStates.ended
+        assert self.state != JingleStates.ENDED
         stanza, jingle = self.__make_jingle('content-reject')
         self.__append_content(jingle, content)
         self.connection.connection.send(stanza)
         # TODO: this will fail if content is not an RTP content
-        gajim.nec.push_incoming_event(JingleDisconnectedReceivedEvent(None,
-            conn=self.connection, jingle_session=self, media=content.media,
-            reason='rejected'))
+        app.nec.push_incoming_event(JingleDisconnectedReceivedEvent(None,
+                                                                      conn=self.connection,
+                                                                      jingle_session=self,
+                                                                      media=content.media,
+                                                                      reason='rejected'))
 
     def __content_modify(self):
-        assert self.state != JingleStates.ended
+        assert self.state != JingleStates.ENDED
 
     def __content_remove(self, content, reason=None):
-        assert self.state != JingleStates.ended
+        assert self.state != JingleStates.ENDED
         if self.connection.connection and self.connection.connected > 1:
             stanza, jingle = self.__make_jingle('content-remove', reason=reason)
             self.__append_content(jingle, content)
             self.connection.connection.send(stanza)
         # TODO: this will fail if content is not an RTP content
-        gajim.nec.push_incoming_event(JingleDisconnectedReceivedEvent(None,
-            conn=self.connection, jingle_session=self, media=content.media,
-            reason='removed'))
+        app.nec.push_incoming_event(JingleDisconnectedReceivedEvent(None,
+                                                                      conn=self.connection,
+                                                                      jingle_session=self,
+                                                                      media=content.media,
+                                                                      reason='removed'))
 
     def content_negotiated(self, media):
-        gajim.nec.push_incoming_event(JingleConnectedReceivedEvent(None,
-            conn=self.connection, jingle_session=self, media=media))
-
-
+        app.nec.push_incoming_event(JingleConnectedReceivedEvent(None,
+                                                                   conn=self.connection,
+                                                                   jingle_session=self,
+                                                                   media=media))
