@@ -1,44 +1,40 @@
 #!/usr/bin/env python3
-# -*- coding:utf-8 -*-
-## src/gajim-remote.py
-##
-## Copyright (C) 2005-2006 Dimitur Kirov <dkirov AT gmail.com>
-##                         Nikos Kouremenos <kourem AT gmail.com>
-## Copyright (C) 2005-2014 Yann Leboulanger <asterix AT lagaule.org>
-## Copyright (C) 2006 Junglecow <junglecow AT gmail.com>
-##                    Travis Shirk <travis AT pobox.com>
-## Copyright (C) 2006-2008 Jean-Marie Traissard <jim AT lapin.org>
-## Copyright (C) 2007 Julien Pivotto <roidelapluie AT gmail.com>
-##
-## This file is part of Gajim.
-##
-## Gajim is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published
-## by the Free Software Foundation; version 3 only.
-##
-## Gajim is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
-##
+
+# Copyright (C) 2005-2006 Dimitur Kirov <dkirov AT gmail.com>
+#                         Nikos Kouremenos <kourem AT gmail.com>
+# Copyright (C) 2005-2014 Yann Leboulanger <asterix AT lagaule.org>
+# Copyright (C) 2006 Junglecow <junglecow AT gmail.com>
+#                    Travis Shirk <travis AT pobox.com>
+# Copyright (C) 2006-2008 Jean-Marie Traissard <jim AT lapin.org>
+# Copyright (C) 2007 Julien Pivotto <roidelapluie AT gmail.com>
+#
+# This file is part of Gajim.
+#
+# Gajim is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published
+# by the Free Software Foundation; version 3 only.
+#
+# Gajim is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 # gajim-remote help will show you the D-BUS API of Gajim
 
 import os
 import sys
 import locale
-import urllib
 import signal
-signal.signal(signal.SIGINT, signal.SIG_DFL) # ^C exits the application
-
 
 from gajim.common import exceptions
-from gajim.common import i18n # This installs _() function
+from gajim.common.i18n import _
 from gajim.common.i18n import Q_
 
+signal.signal(signal.SIGINT, signal.SIG_DFL) # ^C exits the application
+
 try:
     PREFERRED_ENCODING = locale.getpreferredencoding()
 except Exception:
@@ -61,7 +57,7 @@ except Exception:
 
 OBJ_PATH = '/org/gajim/dbus/RemoteObject'
 INTERFACE = 'org.gajim.dbus.RemoteInterface'
-SERVICE = 'org.gajim.dbus'
+SERVICE = 'org.gajim.Gajim'
 BASENAME = 'gajim-remote'
 
 class GajimRemote:
@@ -177,7 +173,7 @@ class GajimRemote:
                         ],
                 'prefs_list': [
                                 _('Lists all preferences and their values'),
-                                [ ]
+                                []
                         ],
                 'prefs_put': [
                                 _('Sets value of \'key\' to \'value\'.'),
@@ -195,7 +191,7 @@ class GajimRemote:
                 'prefs_store': [
                                 _('Writes the current state of Gajim preferences to the .config '
                                         'file'),
-                                [ ]
+                                []
                         ],
                 'remove_contact': [
                                 _('Removes contact from roster'),
@@ -223,7 +219,7 @@ class GajimRemote:
 
                 'get_unread_msgs_number': [
                         _('Returns number of unread messages'),
-                                [ ]
+                                []
                         ],
 
                 'send_xml': [
@@ -334,7 +330,7 @@ class GajimRemote:
 
     def init_connection(self):
         """
-        Create the onnection to the session dbus, or exit if it is not possible
+        Create the connection to the session dbus, or exit if it is not possible
         """
         try:
             self.sbus = dbus.SessionBus()
@@ -373,7 +369,7 @@ class GajimRemote:
             str_ = _('Usage: %(basename)s %(command)s %(arguments)s \n\t %(help)s')\
                     % {'basename': BASENAME, 'command': command,
                     'arguments': arguments_str, 'help': command_props[0]}
-            if len(command_props[1]) > 0:
+            if command_props[1]:
                 str_ += '\n\n' + _('Arguments:') + '\n'
                 for argument in command_props[1]:
                     str_ += ' ' + argument[0] + ' - ' + argument[1] + '\n'
@@ -384,7 +380,7 @@ class GajimRemote:
         """
         Print usage, and list available commands
         """
-        s = _('Usage:\n  %s command [arguments]\n\nCommand is one of:\n' ) % (
+        s = _('Usage:\n  %s command [arguments]\n\nCommand is one of:\n') % (
             BASENAME)
         for command in sorted(self.commands):
             s += '  ' + command
@@ -396,9 +392,9 @@ class GajimRemote:
             s += '\n'
         return s
 
-    def print_info(self, level, prop_dict, encode_return = False):
+    def print_info(self, level, prop_dict, encode_return=False):
         """
-        Return formated string from data structure
+        Return formatted string from data structure
         """
         if prop_dict is None or not isinstance(prop_dict, (dict, list, tuple)):
             return ''
@@ -408,11 +404,11 @@ class GajimRemote:
             spacing = ' ' * level * 4
             for val in prop_dict:
                 if val is None:
-                    ret_str +='\t'
+                    ret_str += '\t'
                 elif isinstance(val, int):
-                    ret_str +='\t' + str(val)
+                    ret_str += '\t' + str(val)
                 elif isinstance(val, str):
-                    ret_str +='\t' + val
+                    ret_str += '\t' + val
                 elif isinstance(val, (list, tuple)):
                     res = ''
                     for items in val:
@@ -440,7 +436,7 @@ class GajimRemote:
                     res = self.print_info(level+1, val)
                     if res != '':
                         ret_str += '%s%s: \n%s' % (spacing, key, res)
-        if (encode_return):
+        if encode_return:
             try:
                 ret_str = ret_str.encode(PREFERRED_ENCODING)
             except Exception:
@@ -480,8 +476,7 @@ class GajimRemote:
         """
         Calls self.method with arguments from sys.argv[2:]
         """
-        args = [i.decode(PREFERRED_ENCODING) for i in self.arguments]
-        args = [dbus.String(i) for i in args]
+        args = [dbus.String(i) for i in self.arguments]
         try:
             res = self.method(*args)
             return res
