@@ -1,51 +1,66 @@
-# -*- coding:utf-8 -*-
-## src/history_manager.py
-##
-## Copyright (C) 2006 Dimitur Kirov <dkirov AT gmail.com>
-## Copyright (C) 2006-2007 Jean-Marie Traissard <jim AT lapin.org>
-##                         Nikos Kouremenos <kourem AT gmail.com>
-## Copyright (C) 2006-2014 Yann Leboulanger <asterix AT lagaule.org>
-## Copyright (C) 2007 Stephan Erb <steve-e AT h3c.de>
-## Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
-##
-## This file is part of Gajim.
-##
-## Gajim is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published
-## by the Free Software Foundation; version 3 only.
-##
-## Gajim is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
-##
+# Copyright (C) 2006 Dimitur Kirov <dkirov AT gmail.com>
+# Copyright (C) 2006-2007 Jean-Marie Traissard <jim AT lapin.org>
+#                         Nikos Kouremenos <kourem AT gmail.com>
+# Copyright (C) 2006-2014 Yann Leboulanger <asterix AT lagaule.org>
+# Copyright (C) 2007 Stephan Erb <steve-e AT h3c.de>
+# Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
+# Copyright (C) 2018 Philipp Hörist <philipp AT hoerist.com>
+#
+# This file is part of Gajim.
+#
+# Gajim is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published
+# by the Free Software Foundation; version 3 only.
+#
+# Gajim is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
-## NOTE: some method names may match those of logger.py but that's it
-## someday (TM) should have common class
-## that abstracts db connections and helpers on it
-## the same can be said for history_window.py
+# NOTE: some method names may match those of logger.py but that's it
+# someday (TM) should have common class
+# that abstracts db connections and helpers on it
+# the same can be said for history.py
 
 import os
 import sys
+import time
+import getopt
+import sqlite3
+from enum import IntEnum, unique
+
 import gi
 gi.require_version('Gtk', '3.0')
+gi.require_version('GLib', '2.0')
+gi.require_version('Gdk', '3.0')
+gi.require_version('Gio', '2.0')
 from gi.repository import Gtk
 from gi.repository import Gdk
 from gi.repository import GLib
-import time
+from gi.repository import Gio
 
-import getopt
+from gajim.common import app
 from gajim.common import i18n
+from gajim.common import configpaths
+from gajim.common.i18n import _
+from gajim.common.const import StyleAttr
 
-def parseOpts():
-    config_path = None
+def is_standalone():
+    # Determine if we are in standalone mode
+    if Gio.Application.get_default() is None:
+        return True
+    if __name__ == '__main__':
+        return True
+    return False
 
+
+if is_standalone():
     try:
-        shortargs = 'hvc:l:p:'
-        longargs = 'help verbose config-path= loglevel= profile='
+        shortargs = 'hvsc:l:p:'
+        longargs = 'help verbose separate config-path= loglevel= profile='
         opts = getopt.getopt(sys.argv[1:], shortargs, longargs.split())[0]
     except getopt.error as msg:
         print(str(msg))
@@ -61,22 +76,20 @@ def parseOpts():
                 '\n  -c, --config-path  ' + _('Choose folder for logfile') + '\n')
             sys.exit()
         elif o in ('-c', '--config-path'):
-            config_path = a
-    return config_path
+            configpaths.set_config_root(a)
 
-config_path = parseOpts()
-del parseOpts
+    configpaths.init()
+    app.load_css_config()
 
-import gajim.common.configpaths
-gajim.common.configpaths.gajimpaths.init(config_path)
-del config_path
-from gajim.common import app
-from gajim import gtkgui_helpers
-from gajim.common.logger import LOG_DB_PATH, JIDConstant, KindConstant
+from gajim.common.const import JIDConstant, KindConstant
 from gajim.common import helpers
-from gajim import dialogs
+from gajim.gtk.dialogs import YesNoDialog
+from gajim.gtk.dialogs import ErrorDialog
+from gajim.gtk.dialogs import ConfirmationDialog
+from gajim.gtk.filechoosers import FileSaveDialog
+from gajim.gtk.util import convert_rgb_to_hex
+from gajim import gtkgui_helpers
 
-from enum import IntEnum, unique
 
 @unique
 class Column(IntEnum):
@@ -86,9 +99,6 @@ class Column(IntEnum):
     NICKNAME = 5
 
 
-import sqlite3 as sqlite
-
-
 class HistoryManager:
     def __init__(self):
         pixs = []
@@ -100,9 +110,10 @@ class HistoryManager:
             # set the icon to all windows
             Gtk.Window.set_default_icon_list(pixs)
 
-        if not os.path.exists(LOG_DB_PATH):
-            dialogs.ErrorDialog(_('Cannot find history logs database'),
-                    '%s does not exist.' % LOG_DB_PATH)
+        log_db_path = configpaths.get('LOG_DB')
+        if not os.path.exists(log_db_path):
+            ErrorDialog(_('Cannot find history logs database'),
+                        '%s does not exist.' % log_db_path)
             sys.exit()
 
         xml = gtkgui_helpers.get_gtk_builder('history_manager.ui')
@@ -119,8 +130,9 @@ class HistoryManager:
         self.jids_already_in = []  # holds jids that we already have in DB
         self.AT_LEAST_ONE_DELETION_DONE = False
 
-        self.con = sqlite.connect(LOG_DB_PATH, timeout=20.0,
-                isolation_level='IMMEDIATE')
+        self.con = sqlite3.connect(
+            log_db_path, timeout=20.0, isolation_level='IMMEDIATE')
+        self.con.execute("PRAGMA secure_delete=1")
         self.cur = self.con.cursor()
 
         self._init_jids_listview()
@@ -225,18 +237,21 @@ class HistoryManager:
 
     def on_history_manager_window_delete_event(self, widget, event):
         if not self.AT_LEAST_ONE_DELETION_DONE:
-            Gtk.main_quit()
+            if is_standalone():
+                Gtk.main_quit()
             return
 
         def on_yes(clicked):
             self.cur.execute('VACUUM')
             self.con.commit()
-            Gtk.main_quit()
+            if is_standalone():
+                Gtk.main_quit()
 
         def on_no():
-            Gtk.main_quit()
+            if is_standalone():
+                Gtk.main_quit()
 
-        dialog = dialogs.YesNoDialog(
+        dialog = YesNoDialog(
             _('Do you want to clean up the database? '
             '(STRONGLY NOT RECOMMENDED IF GAJIM IS RUNNING)'),
             _('Normally allocated database size will not be freed, '
@@ -261,11 +276,10 @@ class HistoryManager:
     def on_jids_listview_selection_changed(self, widget, data=None):
         liststore, list_of_paths = self.jids_listview.get_selection()\
                 .get_selected_rows()
-        paths_len = len(list_of_paths)
-        if paths_len == 0:  # nothing is selected
-            return
 
-        self.logs_liststore.clear()  # clear the store
+        self.logs_liststore.clear()
+        if not list_of_paths:
+            return
 
         self.welcome_vbox.hide()
         self.search_results_scrolledwindow.hide()
@@ -324,8 +338,7 @@ class HistoryManager:
         row = self.cur.fetchone()
         if row is None:
             return False
-        else:
-            return True
+        return True
 
     def _jid_is_room_type(self, jid):
         """
@@ -333,12 +346,7 @@ class HistoryManager:
         """
         self.cur.execute('SELECT type FROM jids WHERE jid = ?', (jid,))
         row = self.cur.fetchone()
-        if row is None:
-            raise
-        elif row[0] == JIDConstant.ROOM_TYPE:
-            return True
-        else:  # normal type
-            return False
+        return row[0] == JIDConstant.ROOM_TYPE
 
     def _fill_logs_listview(self, jid):
         """
@@ -378,16 +386,18 @@ class HistoryManager:
             else:
                 color = None
                 if kind in (KindConstant.SINGLE_MSG_RECV,
-                KindConstant.CHAT_MSG_RECV, KindConstant.GC_MSG):
-                    # it is the other side
-                    color = app.config.get('inmsgcolor')  # so incoming color
+                            KindConstant.CHAT_MSG_RECV,
+                            KindConstant.GC_MSG):
+                    color = app.css_config.get_value(
+                        '.gajim-incoming-nickname', StyleAttr.COLOR)
                 elif kind in (KindConstant.SINGLE_MSG_SENT,
-                KindConstant.CHAT_MSG_SENT):  # it is us
-                    color = app.config.get('outmsgcolor')  # so outgoing color
+                              KindConstant.CHAT_MSG_SENT):
+                    color = app.css_config.get_value(
+                        '.gajim-outgoing-nickname', StyleAttr.COLOR)
                 elif kind in (KindConstant.STATUS,
-                KindConstant.GCSTATUS):  # is is statuses
-                    # so status color
-                    color = app.config.get('statusmsgcolor')
+                              KindConstant.GCSTATUS):
+                    color = app.css_config.get_value(
+                        '.gajim-status-message', StyleAttr.COLOR)
                     # include status into (status) message
                     if message is None:
                         message = ''
@@ -398,10 +408,11 @@ class HistoryManager:
 
                 message_ = '<span'
                 if color:
-                    message_ += ' foreground="%s"' % color
+                    message_ += ' foreground="%s"' % convert_rgb_to_hex(color)
                 message_ += '>%s</span>' % GLib.markup_escape_text(message)
-                self.logs_liststore.append((str(log_line_id), str(jid_id),
-                    time_, message_, subject, nickname))
+                self.logs_liststore.append(
+                    (str(log_line_id), str(jid_id),
+                     time_, message_, subject, nickname))
 
     def _fill_search_results_listview(self, text):
         """
@@ -454,24 +465,14 @@ class HistoryManager:
             return True
 
     def on_export_menuitem_activate(self, widget):
-        xml = gtkgui_helpers.get_gtk_builder('history_manager.ui',
-            'filechooserdialog')
-        xml.connect_signals(self)
+        FileSaveDialog(self._on_export,
+                       transient_for=self.window,
+                       modal=True)
 
-        dlg = xml.get_object('filechooserdialog')
-        dlg.set_title(_('Exporting History Logs…'))
-        dlg.set_current_folder(app.HOME_DIR)
-        dlg.props.do_overwrite_confirmation = True
-        response = dlg.run()
-
-        if response == Gtk.ResponseType.OK:  # user want us to export ;)
-            liststore, list_of_paths = self.jids_listview.get_selection()\
-                    .get_selected_rows()
-            path_to_file = dlg.get_filename()
-            self._export_jids_logs_to_file(liststore, list_of_paths,
-                path_to_file)
-
-        dlg.destroy()
+    def _on_export(self, filename):
+        liststore, list_of_paths = self.jids_listview.get_selection()\
+                .get_selected_rows()
+        self._export_jids_logs_to_file(liststore, list_of_paths, filename)
 
     def on_delete_menuitem_activate(self, widget, listview):
         widget_name = Gtk.Buildable.get_name(listview)
@@ -513,7 +514,7 @@ class HistoryManager:
         # AT THIS TIME FIRST EXECUTE IS LOST! WTH!!!!!
         results = self.cur.fetchall()
         #print results[0]
-        file_ = open(path_to_file, 'w')
+        file_ = open(path_to_file, 'w', encoding='utf-8')
         for row in results:
             # in store: time, kind, message, contact_name FROM logs
             # in text: JID or You or nickname (if it's gc_msg), time, message
@@ -578,7 +579,7 @@ class HistoryManager:
         else:
             pri_text = _(
                 'Do you wish to delete all correspondence with the selected contacts?')
-        dialog = dialogs.ConfirmationDialog('',
+        dialog = ConfirmationDialog('',
             _('This can not be undone.'), on_response_ok=(on_ok,
             liststore, list_of_paths))
         dialog.set_title(_('Deletion Confirmation'))
@@ -617,7 +618,7 @@ class HistoryManager:
         pri_text = i18n.ngettext(
             'Do you really want to delete the selected message?',
             'Do you really want to delete the selected messages?', paths_len)
-        dialog = dialogs.ConfirmationDialog(pri_text,
+        dialog = ConfirmationDialog(pri_text,
             _('This is an irreversible operation.'), on_response_ok=(on_ok,
             liststore, list_of_paths))
         dialog.set_title(_('Deletion Confirmation'))
@@ -638,7 +639,7 @@ class HistoryManager:
 
     def on_search_results_listview_row_activated(self, widget, path, column):
         # get log_line_id, jid_id from row we double clicked
-        log_line_id = self.search_results_liststore[path][0]
+        log_line_id = str(self.search_results_liststore[path][0])
         jid = self.search_results_liststore[path][1]
         # make it string as in gtk liststores I have them all as strings
         # as this is what db returns so I don't have to fight with types
@@ -659,13 +660,14 @@ class HistoryManager:
 
         iter_ = self.logs_liststore.get_iter_first()
         while iter_:
-            # self.logs_liststore[iter_][0] holds lon_line_ids
+            # self.logs_liststore[iter_][0] holds log_line_ids
             if self.logs_liststore[iter_][0] == log_line_id:
                 break
             iter_ = self.logs_liststore.iter_next(iter_)
 
         path = self.logs_liststore.get_path(iter_)
         self.logs_listview.scroll_to_cell(path)
+        self.logs_listview.get_selection().select_path(path)
 
 
 def main():
